[FFmpeg-soc] [soc]: r4985 - amr/amrnbdec.c

cmcq subversion at mplayerhq.hu
Sat Aug 8 21:50:00 CEST 2009


Author: cmcq
Date: Sat Aug  8 21:49:59 2009
New Revision: 4985

Log:
Moving bits from a packed format is just unpacking, not decoding

Modified:
   amr/amrnbdec.c

Modified: amr/amrnbdec.c
==============================================================================
--- amr/amrnbdec.c	Sat Aug  8 21:47:46 2009	(r4984)
+++ amr/amrnbdec.c	Sat Aug  8 21:49:59 2009	(r4985)
@@ -113,7 +113,7 @@ static av_cold int amrnb_decode_init(AVC
 
 
 /**
  * Decode an RFC4867 speech frame into the AMR frame mode and parameters.
  *
  * The order of speech bits is specified by 3GPP TS 26.101.
  *
@@ -123,7 +123,7 @@ static av_cold int amrnb_decode_init(AVC
  *
  * @return the frame mode
  */
-static enum Mode decode_bitstream(AMRContext *p, const uint8_t *buf,
+static enum Mode unpack_bitstream(AMRContext *p, const uint8_t *buf,
                                   int buf_size)
 {
     GetBitContext gb;
@@ -1048,7 +1048,7 @@ static int amrnb_decode_frame(AVCodecCon
     float synth_fixed_gain;                  // the fixed gain that synthesis should use
     float *synth_fixed_vector;               // pointer to the fixed vector that synthesis should use
 
-    p->cur_frame_mode = decode_bitstream(p, buf, buf_size);
+    p->cur_frame_mode = unpack_bitstream(p, buf, buf_size);
     if (p->cur_frame_mode == MODE_DTX) {
         av_log_missing_feature(avctx, "dtx mode", 1);
         return -1;
@@ -113,7 +113,7 @@ static av_cold int amrnb_decode_init(AVC
 
 /**
- * Decode an RFC4867 speech frame into the AMR frame mode and parameters.
+ * Unpack an RFC4867 speech frame into the AMR frame mode and parameters.
  *
  * The order of speech bits is specified by 3GPP TS 26.101.


More information about the FFmpeg-soc mailing list